@@ -1,4 +1,4 @@
-## Copyright (C) 2012-2020\1 Philip Nienhuis
+## Copyright (C) 2012-2026 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -17,7 +17,7 @@
 ## @deftypefn {Function File} {@var{rslts}] =} io_testscript (@var{intf1})
 ## @deftypefnx {Function File} {@var{rslts}] =} io_testscript (@var{intf1}, @var{fname})
 ## @deftypefnx {Function File} {@var{rslts}] =} io_testscript (@var{intf1}, @var{fname}, @var{intf2})
-## @deftypefnx {Function File} {@var{rslts}] =} io_testscript (@var{intf1}, @var{fname}, @var{intf2}, @var{vebose})
+## @deftypefnx {Function File} {@var{rslts}] =} io_testscript (@var{intf1}, @var{fname}, @var{intf2}, @var{verbose})
 ## Try to check proper operation of spreadsheet I/O scripts using interface
 ## @var{intf1}.
 ##
@@ -38,7 +38,7 @@
 ## (e.g., test_spsh.m) optional output argument @var{rslts} is supplied.  The
 ## results of all test steps are printed on the terminal.
 ##
-## @seealso {test_spsh}
+## @seealso{test_spsh}
 ##
 ## @end deftypefn
 
@@ -245,14 +245,14 @@ function rslts = io_testscript (intf, fname="io-test.xlsx", intf2=[], verbose=fa
       endif
     end_try_catch
 
-    ## 10. Clean up
-    printf ("\n10. Cleaning up.....");
-    delete (fname);
-    printf (" OK\n");
   catch
     ## Just to preserve rslts array
-    printf ("\n%s\n\n", lasterr ());
+    printf ("\n%s\n", lasterr ());
   end_try_catch
 
+  ## 10. End of tests. Be sure to remove spreadsheet file.
+  printf ("\n10. Cleaning up.....\n\n");
+  delete (fname);
+
 endfunction
 
