@@ -1,15 +1,15 @@
-## Copyright (C) 2012-2019 Philip Nienhuis
-## 
+## Copyright (C) 2012-2026 Philip Nienhuis
+##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 3 of the License, or
 ## (at your option) any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <http://www.gnu.org/licenses/>.
@@ -26,7 +26,7 @@ function [ xls ] = __COM_spsh_close__ (xls)
     ## Note: COM / VB supports other Excel file formats as FileFormatNum
     ## or xlFileFormat (see below switch stmt):
     ## (see Excel Help, VB reference, Enumerations, xlFileType)
-    
+
     ## xls.changed = 0: no changes: just close;
     ##               1: existing file with changes: save, close.
     ##               2: new file with data added: save, close
@@ -44,6 +44,7 @@ function [ xls ] = __COM_spsh_close__ (xls)
         if (xls.changed == 2)
           ## Probably a newly created, or renamed, Excel file. Get proper format
           [~, ~, ext] = fileparts (fname);
+          ## https://docs.microsoft.com/en-us/office/vba/api/excel.xlfileformat
           switch ext
             case ".txt"
               ## Current Platform Text
@@ -57,18 +58,24 @@ function [ xls ] = __COM_spsh_close__ (xls)
             case ".csv"
               ## CSV (general, not platform-specific)
               xlFileFormat = 6;
+            case ".dbf"
+              ## dBase 3 format (xDbf3). Note; xlDBf2 = 7, xlDBF4 = 11
+              xlFileFormat = 8;
             case ".dif"
               ## Data Interchange format
               xlFileFormat = 9;
-            case ".dbf"
-              ## DBase 3
-              xlFileFormat = 8;
+            case ".wk3"
+              ## Lotus-1-2-3
+              xlFileFormat = 15;
             case ".wq1"
               ## Quattro Pro format
               xlFileFormat = 34;
             case ".prn"
               ## Printer Text
               xlFileFormat = 36;
+            case ".wk4"
+              ## Lotus 1-2-3
+              xlFileFormat = 38;
             case {".htm", ".html"}
               ## HTML format
               xlFileFormat = 44;
@@ -93,6 +100,9 @@ function [ xls ] = __COM_spsh_close__ (xls)
             case ".pdf"
               ## Printer Text
               xlFileFormat = 57;
+            case ".ods"
+              ## Open Document Format
+              xlFileFormat = 60;
             otherwise
               ## Fall back to OpenXML .xlsx
               xlFileFormat = 51;
