@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2019 Philip Nienhuis
+## Copyright (C) 2009-2026 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -33,7 +33,7 @@
 ##   [xlso, status] = __JXL_oct2spsh__ ('arr', xlsi, 'Third_sheet', 'AA31');
 ## @end example
 ##
-## @seealso {oct2xls, xls2oct, xlsopen, xlsclose, xlsread, xlswrite, xls2jxla2oct}
+## @seealso{oct2xls, xls2oct, xlsopen, xlsclose, xlsread, xlswrite, xls2jxla2oct}
 ##
 ## @end deftypefn
 
@@ -44,7 +44,7 @@ function [ xls, rstatus ] = __JXL_oct2spsh__ (obj, xls, wsh, crange, spsh_opts)
 
   ## Preliminary sanity checks
   if (strcmpi (xls.filename(end-4:end-1), ".xls"))  ## No OOXML in JXL
-    error ("JXL interface can only process Excel .xls files")
+    error ("oct2xls: JXL interface can only process Excel .xls files")
   endif
 
   persistent ctype;
@@ -80,7 +80,7 @@ function [ xls, rstatus ] = __JXL_oct2spsh__ (obj, xls, wsh, crange, spsh_opts)
         ++ii;
       endwhile
       if (ii >= 5)
-        error (sprintf( " > 5 sheets named [_]Sheet%d already present!", wsh));
+        error (sprintf( "oct2xls: > 5 sheets named [_]Sheet%d already present!", wsh));
       endif
       sh = wb.createSheet (strng, nr_of_sheets); ++nr_of_sheets;
       xls.changed = min (xls.changed, 2);    ## Keep a 2 in case of new file
@@ -104,7 +104,7 @@ function [ xls, rstatus ] = __JXL_oct2spsh__ (obj, xls, wsh, crange, spsh_opts)
   [topleft, nrows, ncols, trow, lcol] = ...
                     spsh_chkrange (crange, nr, nc, xls.xtype, xls.filename);
   if (nrows < nr || ncols < nc)
-    warning ("Array truncated to fit in range\n");
+    warning ("oct2xls: array truncated to fit in range\n");
     obj = obj(1:nrows, 1:ncols);
   endif
 
@@ -112,7 +112,7 @@ function [ xls, rstatus ] = __JXL_oct2spsh__ (obj, xls, wsh, crange, spsh_opts)
   typearr = spsh_prstype (obj, nrows, ncols, ctype, spsh_opts);
   if (! spsh_opts.formulas_as_text)
     ## Remove leading '=' from formula strings
-    fptr = ! (4 * (ones (size (typearr))) .- typearr);
+    fptr = ! (4 * (ones (size (typearr))) - typearr);
     obj(fptr) = cellfun (@(x) x(2:end), obj(fptr), "Uniformoutput", false);
   endif
   clear fptr
