@@ -1,20 +1,20 @@
-## Copyright (C) 2013-2017 Philip Nienhuis
-## 
+## Copyright (C) 2013-2026 Philip Nienhuis
+##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 3 of the License, or
 ## (at your option) any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <http://www.gnu.org/licenses/>.
 
-## -*- texinfo -*- 
+## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{retval} =} __OCT_spsh_info__ (@var{x} @var{y})
 ##
 ## @seealso{}
@@ -29,13 +29,26 @@ function [ sh_names ] = __OCT_spsh_info__ (ods)
 
   sh_names(:, 1) = ods.sheets.sh_names;
   for ii=1:numel (ods.sheets.sh_names)
-    [ tr, lr, lc, rc ] = getusedrange (ods, ii);
-    if (tr)
-      sh_names(ii, 2) = sprintf ("%s:%s", calccelladdress (tr, lc),...
-                        calccelladdress (lr, rc));
+    if (ods.sheets.type(ii) == 1)
+      [ tr, lr, lc, rc ] = getusedrange (ods, ods.sheets.shId(ii));
+      if (tr)
+        sh_names(ii, 2) = sprintf ("%s:%s", calccelladdress (tr, lc),...
+                          calccelladdress (lr, rc));
+      else
+        sh_names(ii, 2) = "Empty";
+      endif
+    elseif (ods.sheets.type(ii) == 2)
+      sh_names(ii, 2) = "Chart";
     else
-      sh_names(ii, 2) = "Empty";
+      sh_names(ii, 2) = "Other type";
     endif
   endfor
+  ## Replace XML escape sequences by regular characters
+  sh_names(:, 1) = strrep (sh_names(:, 1), "&amp;",  "&");
+  sh_names(:, 1) = strrep (sh_names(:, 1), "&lt;",   "<");
+  sh_names(:, 1) = strrep (sh_names(:, 1), "&gt;",   ">");
+  sh_names(:, 1) = strrep (sh_names(:, 1), "&apos;", "'");
+  sh_names(:, 1) = strrep (sh_names(:, 1), "&quot;",  '"');
+
 
 endfunction
