@@ -1,5 +1,5 @@
-## Copyright (C) 2013-2021 Philip Nienhuis
-## Copyright (C) 2013-2020 Markus Bergholz (.xlsx & archive unzip stuff)
+## Copyright (C) 2013-2026 Philip Nienhuis
+## Copyright (C) 2013-2026 Markus Bergholz (.xlsx & archive unzip stuff)
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ function [ xls, xlssupport, lastintf] = __OCT_spsh_open__ (xls, xwrite, filename
   opwd = pwd;
   if (ftype == 5)
     ## Gnumeric xml files are gzipped
-    system (sprintf ('gzip -d -c -S=gnumeric "%s" > %s', templ, tmpdir));
+    [dum1, dum2] = system (sprintf ('gzip -d -c -S=gnumeric "%s" > %s', templ, tmpdir));
     fid = fopen (tmpdir, 'r');
     xml = fread (fid, "char=>char").';
     ## Close file handle, don't delete file
@@ -126,11 +126,11 @@ function [ xls, xlssupport, lastintf] = __OCT_spsh_open__ (xls, xwrite, filename
         relids(ii, 3) = "0";
       endfor
 
-      id = find (strncmpi ("worksheets", relids(:, 2), 10));
+      id = find (! cellfun(@isempty, strfind (lower (relids(:, 2)), "worksheets")));
       relids(id, 3) = "1";
       rels = str2double (cell2mat (cell2mat ( ...
                                    regexp (relids(id, :), '(\d+)', "tokens"))));
-      id = find (strncmp ("chartsheets", relids(:, 2), 11));
+      id = find (! cellfun(@isempty, strfind (lower (relids(:, 2)), "chartsheets")));
       if (! isempty (id))
         relids(id, 3) = "2";
         rels = [rels; (str2double (cell2mat (cell2mat ( ...
