@@ -1,15 +1,15 @@
-## Copyright (C) 2012-2020 Philip Nienhuis
-## 
+## Copyright (C) 2012-2026 Philip Nienhuis
+##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 3 of the License, or
 ## (at your option) any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <http://www.gnu.org/licenses/>.
@@ -37,7 +37,7 @@ function [ ods, odssupport, lastintf ] = __OTK_spsh_open__ (ods, rw, filename, o
           javaMethod ("getApplicationVersion", "org.odftoolkit.odfdom.Version");
       end_try_catch
       ## For odfdom-incubator (= 0.8.8+), strip extra info
-      odfvsn = regexp (odfvsn, '\d\.\d\.\d+', "match"){1};
+      odfvsn = regexp (odfvsn, '\d\.\d+\.\d+', "match"){1};
     endif
 
     odftk = "org.odftoolkit.odfdom.doc";
