@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2025 by Philip Nienhuis
+## Copyright (C) 2009-2026 by Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -163,10 +163,11 @@
 ## and columns.  Be aware that the COM interface does the same for
 ## @var{rawarr}, so any returned array may turn out to be smaller than
 ## requested in @var{range}.  Use the last return argument @var{LIMITS}
-## for info on the cell ranges your data came from.
-## If you don't want the output to be trimmed, specify an Options struct
-## containing a field "strip_array" with contents 0 or false as extra
-## input argument (see above).
+## for info on the cell ranges your data came from. @*
+## The (optional) third output @var{rawarr} is by default not trimmed
+## from empty outer rows and columns.  If you do want @var{rawarr} to be
+## trimmed, specify an Options struct containing a field "strip_array"
+## with contents 1 or true as extra input argument (see above).
 ##
 ## Remarks: @*
 ## --------
@@ -274,17 +275,19 @@
 ##
 ## @example
 ##   [An, Tn, Ra, limits] = xlsread ('Sales2009.ods', 'Third_sheet');
-##   (which returns all data in worksheet 'Third_sheet' in file 'Sales2009.ods'
-##   into array An, the text data into array Tn, the raw cell data into
-##   cell array Ra and the ranges from where the actual data came in limits)
+##   (which returns all data in worksheet 'Third_sheet' in file
+##   'Sales2009.ods' into array An, the text data into array Tn, the
+##   raw cell data into cell array Ra and the ranges from where the
+##   actual data came in limits)
 ## @end example
 ##
 ## How to select an interface; in this example two:
 ##
 ## @example
 ##   numarr = xlsread ('Sales2010.xls', 4, [], @{'JXL', 'COM'@});
-##   (Read all data from 4th worksheet in file Sales2010.xls using either JXL
-##    or COM interface (i.e, exclude POI, OXS, UNO and OCT interfaces).
+##   (Read all data from 4th worksheet in file Sales2010.xls using
+##   either JXL or COM interface (i.e, exclude POI, OXS, UNO and OCT
+##   interfaces).
 ## @end example
 ##
 ## @seealso{xlswrite, xlsopen, xls2oct, parsecell, xlsclose, xlsfinfo, oct2xls}
@@ -317,7 +320,8 @@ function [ numarr, txtarr, rawarr, varargout ] = xlsread (fn, wsh, datrange, var
       wsh = 1;
     endif
   endif
-  reqintf = hndl = opts = extout = [];
+  reqintf = hndl = extout = [];
+  opts = struct ("strip_array", false);
 
   ## Process additional input arguments beyond #3
   verbose = false;
@@ -334,7 +338,7 @@ function [ numarr, txtarr, rawarr, varargout ] = xlsread (fn, wsh, datrange, var
       elseif (strcmp (class (varargin{ii}), "function_handle"))
         ## Function handle to apply to output "num"
         hndl = varargin{ii};
-      elseif (isstruct(varargin{ii}))
+      elseif (isstruct (varargin{ii}))
         ## Options struct. It will be validated in xls2oct, just convey here.
         opts = varargin{ii};
       elseif ((isnumeric (varargin{ii}) && isreal (varargin{ii}) && ...
@@ -348,7 +352,7 @@ function [ numarr, txtarr, rawarr, varargout ] = xlsread (fn, wsh, datrange, var
   endif
 
   rawarr = txtarr = {};
-  numarr = varagout{1} = varargout{2} = [];
+  numarr = varargout{1} = varargout{2} = [];
 
   ## Checks done. First check for .csv as that doesn't need xlsopen etc;
   ## a convenience for lazy Matlab users (see bugs #40993 & #44511).
